package main

import (
	"flag"
	"log"
	"os"
	"os/signal"
	"syscall"

	"git.autistici.org/ale/radioai"
	"git.autistici.org/ale/radioai/node"
)

var (
	publicIp = flag.String("ip", "127.0.0.1", "Public IP for this machine")
)


func main() {
	flag.Parse()

	client := radioai.NewEtcdClient()
	n := node.NewRadioNode(*publicIp, client)

	// Set up a clean shutdown function on SIGTERM.
	stopch := make(chan os.Signal)
	go func() {
		<- stopch
		log.Printf("terminating...")
		n.Stop()
	}()
	signal.Notify(stopch, syscall.SIGTERM, syscall.SIGINT)

	n.Run()
}
