package main

import (
	"flag"
	"fmt"
	"log"
	"net/http"
	"time"

	"git.autistici.org/ale/radioai"
	"git.autistici.org/ale/radioai/fe"
)

var (
	domain = flag.String("domain", "", "DNS domain to serve")
	dnsPort = flag.Int("dns-port", 53, "DNS port")
	httpPort = flag.Int("http-port", 80, "HTTP port")
	publicIp = flag.String("ip", "127.0.0.1", "Public IP for this machine")

	// Default DNS TTL (seconds).
	dnsTtl = 5
)

func main() {
	flag.Parse()

	if *domain == "" {
		log.Fatal("Must specify --domain")
	}

	client := radioai.NewEtcdClient()
	api := radioai.NewRadioAPI(client)
	red := fe.NewHttpRedirector(api)

	dnsRed := fe.NewDnsRedirector(api, *domain, *publicIp, dnsTtl)
	dnsRed.Run(fmt.Sprintf(":%d", *dnsPort))

	httpServer := &http.Server{
		Addr: fmt.Sprintf(":%d", *httpPort),
		Handler: red,
		ReadTimeout: 10 * time.Second,
		WriteTimeout: 10 * time.Second,
	}

	log.Printf("starting HTTP server on %s/tcp", httpServer.Addr)
	log.Fatal(httpServer.ListenAndServe())
}
